@@ -24,6 +24,7 @@
 
 #include "ev-document.h"
 #include "ev-link.h"
+#include "ev-view-accessible.h"
 
 G_BEGIN_DECLS
 
@@ -63,6 +64,7 @@ void		ev_view_set_document	  (EvView         *view,
 /* Clipboard */
 void		ev_view_copy		  (EvView         *view);
 void		ev_view_select_all	  (EvView         *view);
+gboolean        ev_view_get_has_selection (EvView         *view);
 
 /* sizing and behavior */
 /* These are all orthoganal to each other, except 'presentation' trumps all
@@ -118,9 +120,13 @@ const char     *ev_view_get_find_status   (EvView         *view);
 void           ev_view_hide_cursor        (EvView         *view);
 void           ev_view_show_cursor        (EvView         *view);
 
-/* Scrolling */
+/* Navigation */
 void	       ev_view_scroll             (EvView         *view,
 	                                   EvScrollType    scroll);
+void	       ev_view_goto_link          (EvView         *view,
+					   EvLink         *link);
+gboolean       ev_view_next_page	  (EvView         *view);
+gboolean       ev_view_previous_page	  (EvView         *view);
 
 G_END_DECLS
 
